UnauthorizedServerFailure class

Implemented types

Constructors

UnauthorizedServerFailure({String? code, String? serverStack, List<String> messages = const [], int? statusCode, String? original, BaseRequest? request})

Properties

code → String?
final
hashCode → int
The hash code for this object.
no setteroverride
message → String
no setteroverride
messages → List<String>
final
original → String?
final
request → BaseRequest?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverStack → String?
final
statusCode → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override