FileResource class abstract

Implementers

Constructors

FileResource()

Properties

createdAt DateTime
no setter
fileUrl String
no setter
hashCode int
The hash code for this object.
no setterinherited
hqThumbnail String?
no setter
id String
no setter
isImage bool
no setter
isVideo bool
no setter
lqThumbnail String?
no setter
mimeType String
no setter
resourceType String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnails → BuiltList<String>
no setter
updatedAt DateTime?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited