UserModelBuilder class

Constructors

UserModelBuilder()

Properties

accountConfirmedAt ↔ DateTime?
getter/setter pair
active ↔ bool?
getter/setter pair
createdAt ↔ DateTime?
getter/setter pair
email ↔ String?
getter/setter pair
firstName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
lastName ↔ String?
getter/setter pair
profilePictureUrl ↔ String?
getter/setter pair
revoked ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt ↔ DateTime?
getter/setter pair
username ↔ String?
getter/setter pair

Methods

build() → UserModel
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(UserModel other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(UserModelBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited